StringRecord

Struct StringRecord 

pub struct StringRecord { /* private fields */ }
An owned, decoded & unquoted/unescaped representation of a CSV record.

StringRecord are typically used with a Reader.

Creating a StringRecord:

use simd_csv::StringRecord;

let mut record = StringRecord::new();
record.push_field("john");
record.push_field("landis");

Implementations

Source

impl StringRecord

pub fn new() -> Self

Create an empty record

pub fn as_byte_record(&self) -> &ByteRecord

Return a reference to the underlying ByteRecord backing this record.

pub fn len(&self) -> usize

Return the number of fields of the record.

pub fn is_empty(&self) -> bool

Return whether the record is empty.

pub fn clear(&mut self)

Clear the record completely.

pub fn get(&self, index: usize) -> Option<&str>

Return field at index. Will return None if index is out of bounds.

pub fn iter(&self) -> StringRecordIter<'_>

Return an iterator over the record’s fields.

pub fn push_field(&mut self, field: &str)

Append a new field to the back of the record.