pub struct StringRecord { /* private fields */ }Expand description
An owned, decoded & unquoted/unescaped representation of a CSV record.
StringRecord are typically used with a Reader.
Creating a StringRecord:
use simd_csv::StringRecord;
let mut record = StringRecord::new();
record.push_field("john");
record.push_field("landis");Implementations
Sourceimpl StringRecord
impl StringRecord
Sourcepub fn as_byte_record(&self) -> &ByteRecord
pub fn as_byte_record(&self) -> &ByteRecord
Return a reference to the underlying ByteRecord backing this record.
Sourcepub fn get(&self, index: usize) -> Option<&str>
pub fn get(&self, index: usize) -> Option<&str>
Return field at index. Will return None if index is out of bounds.
Sourcepub fn push_field(&mut self, field: &str)
pub fn push_field(&mut self, field: &str)
Append a new field to the back of the record.